---
# generated by https://github.com/hashicorp/terraform-plugin-docs
page_title: "vercel_prebuilt_project Data Source - terraform-provider-vercel"
subcategory: ""
description: |-
  Provides the output of a project built via vercel build and provides metadata for use with a vercel_deployment
  The build command https://vercel.com/docs/cli#commands/build can be used to build a project locally or in your own CI environment.
  Build artifacts are placed into the .vercel/output directory according to the Build Output API https://vercel.com/docs/build-output-api/v3.
  This allows a Vercel Deployment to be created without sharing the Project's source code with Vercel.
---

# vercel_prebuilt_project (Data Source)

Provides the output of a project built via `vercel build` and provides metadata for use with a `vercel_deployment`

The [build command](https://vercel.com/docs/cli#commands/build) can be used to build a project locally or in your own CI environment. 
Build artifacts are placed into the `.vercel/output` directory according to the [Build Output API](https://vercel.com/docs/build-output-api/v3).

This allows a Vercel Deployment to be created without sharing the Project's source code with Vercel.

## Example Usage

```terraform
# In this example, we are assuming that a nextjs UI exists in a `ui` directory 
# and has been prebuilt via `vercel build`. 
# We assume any terraform code exists in a separate `terraform` directory.
# E.g.
# ```
# ui/
#    .vercel/
#        output/ 
#            ...
#    src/
#        index.js
#    package.json
#    ...
# terraform/
#    main.tf
#    ...
# ```

data "vercel_project" "example" {
  name = "my-awesome-project"
}

data "vercel_prebuilt_project" "example" {
  path = "../ui"
}

resource "vercel_deployment" "example" {
  project_id  = data.vercel_project.example.id
  files       = data.vercel_prebuilt_project.example.output
  path_prefix = data.vercel_prebuilt_project.example.path
}
```

<!-- schema generated by tfplugindocs -->
## Schema

### Required

- `path` (String) The path to the project. Note that this path is relative to the root of your terraform files. This should be the directory that contains the `.vercel/output` directory.

### Read-Only

- `id` (String) The ID of this resource.
- `output` (Map of String) A map of output file to metadata about the file. The metadata contains the file size and hash, and allows a deployment to be created if the file changes.


